"""
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
"""
from models.multicluster import MultiCluster


def get_info(session, session_manager, cluster_manager, xdr_port):
    # Get current session
    if session:
        if 'session' in session:
            session_key = session['session']
        else:
            return dict(status='failure', error='No session found')
    else:
        return dict(status='failure', error='No session found')

    # Get clusters from session
    clusters = session_manager.get_clusters_from_session(session_key)
    if not clusters:
        return dict(status='failure', error='No cluster object found')

    # Get one cluster object
    cluster_id = clusters.pop()['cluster_id']
    cluster_obj = cluster_manager.get_cluster_by_id(cluster_id)

    # Get multicluster object from session
    multicluster_obj = session_manager.get_multicluster(session_key)

    # Check xdr_port type
    try:
        xdr_port = int(xdr_port)
    except ValueError:
        # Set to default port
        xdr_port = 3004

    if not multicluster_obj:
        # Create new multicluster object if not present
        cluster_name = session_manager.get_cluster_name(
            session_key, cluster_id)
        multicluster_obj = MultiCluster(
            cluster_id, cluster_obj, cluster_name, xdr_port)
        # Add multicluster object to session
        session_manager.add_multicluster(session_key, multicluster_obj)

    # Get all explored cluster objects in multicluster obj
    # Compare it with cluster objects in session_manager
    mc_discovered_objects = multicluster_obj.get_discovered_cluster_objects(
        ).values()
    # Add cluster objects that are not already present in mc
    while True:
        if cluster_obj not in mc_discovered_objects:
            if not cluster_obj.get_mc_dependent():
                cluster_name = session_manager.get_cluster_name(
                    session_key, cluster_id)
                multicluster_obj.add_cluster_object(
                    cluster_id, cluster_obj, cluster_name, xdr_port)
        if not clusters:
            break
        cluster_id = clusters.pop()['cluster_id']
        cluster_obj = cluster_manager.get_cluster_by_id(cluster_id)

    response = dict(
        status="success",
        data=multicluster_obj.get_multicluster_data(
            xdr_port, session, session_manager, cluster_manager)
    )
    return response
