# -*- coding: utf-8 -*-

import os, sys
# ensure citruleaf.py is in path
sys.path.insert(1, os.path.realpath( os.pardir ) )

import unittest
import citrusleaf as cl

class TestQueryUser(unittest.TestCase):

    @classmethod
    def setUpClass(cls):
        
        cls.cluster_with_user_admin = cl.CitrusleafCluster()
        cls.cluster_with_user_admin.setUser('testuauser', cl.hashpassword('aerospike'))
        cl.cluster_setHost(cls.cluster_with_user_admin, 'localhost', '3000')

        cls.cluster_with_read_user = cl.CitrusleafCluster()
        cls.cluster_with_read_user.setUser('testreaduser', cl.hashpassword('aerospike'))
        cl.cluster_setHost(cls.cluster_with_read_user, 'localhost', '3000')
    
    @classmethod
    def tearDownClass(cls):

        del(cls.cluster_with_user_admin)
        del(cls.cluster_with_read_user)
   
    def test_queryUser_for_present_user(self):
        
        user = cl.queryUser(TestQueryUser.cluster_with_user_admin, 'testreaduser')

        self.assertEqual(0, user[0])
        self.assertEqual('testreaduser', user[1].name)
        self.assertEqual(['read'], user[1].roles)
    
    def test_queryUser_for_abscent_user(self):

        user = cl.queryUser(TestQueryUser.cluster_with_user_admin, 'some_non_user')

        self.assertEqual(60, user[0])
        self.assertIsNone(user[1])

    def test_queryUser_with_invalid_cluster(self):

        self.assertEqual(0, 0)

    def test_queryUser_with_other_than_useradmin_user(self):
        
        user = cl.queryUser(TestQueryUser.cluster_with_read_user, "testsauser")
        
        self.assertEqual(81, user[0])
        self.assertIsNone(user[1])

    def test_queryUser_for_self_info(self):
        
        user = cl.queryUser(TestQueryUser.cluster_with_read_user, "testreaduser")
        
        self.assertEqual(0, user[0])
        self.assertEqual('testreaduser', user[1].name)
        self.assertEqual(['read'], user[1].roles)

    def test_queryUser_for_self_info_with_more_than_one_role(self):

        status = cl.grantRoles(TestQueryUser.cluster_with_user_admin, "testreaduser", roles=["read-write", "sys-admin"])

        self.assertEqual(0, status)

        user = cl.queryUser(TestQueryUser.cluster_with_read_user, "testreaduser")

        self.assertEqual(0, user[0])
        self.assertEqual('testreaduser', user[1].name)
        self.assertEqual(['read', 'read-write', 'sys-admin'].sort(), user[1].roles.sort())

        status = cl.replaceRoles(TestQueryUser.cluster_with_user_admin, "testreaduser", ['read'])

        self.assertEqual(0, status)

    def test_queryUser_with_other_than_useradmin_user_with_multiple_roles(self):

        status = cl.grantRoles(TestQueryUser.cluster_with_user_admin, "testreaduser", roles=["read-write", "sys-admin"])

        self.assertEqual(0, status)

        user = cl.queryUser(TestQueryUser.cluster_with_read_user, "testsauser")

        self.assertEqual(81, user[0])
        self.assertIsNone(user[1])

        status = cl.replaceRoles(TestQueryUser.cluster_with_user_admin, "testreaduser", ['read'])

        self.assertEqual(0, status)
       
if __name__ == "__main__":
    unittest.main()
